@@ -43,21 +43,47 @@ struct _TrackerMinerRSSPrivate {
 	gint now_fetching;
 	GDBusConnection *connection;
 	guint graph_updated_id;
+
+	GList *item_inserts;
+	GHashTable *channel_updates;
 };
 
-static void         miner_started               (TrackerMiner    *miner);
-static void         miner_stopped               (TrackerMiner    *miner);
-static void         miner_paused                (TrackerMiner    *miner);
-static void         miner_resumed               (TrackerMiner    *miner);
-static void         retrieve_and_schedule_feeds (TrackerMinerRSS *miner);
-static void         change_status               (FeedsPool       *pool,
-                                                 FeedChannel     *feed,
-                                                 gpointer         user_data);
-static void         feed_fetched                (FeedsPool       *pool,
-                                                 FeedChannel     *feed,
-                                                 GList           *items,
-                                                 gpointer         user_data);
-static const gchar *get_message_url             (FeedItem        *item);
+typedef struct {
+	TrackerMinerRSS *miner;
+	FeedChannel *channel;
+	gint timeout_id;
+	GCancellable *cancellable;
+} FeedChannelUpdateData;
+
+typedef struct {
+	TrackerMinerRSS *miner;
+	FeedItem *item;
+	GCancellable *cancellable;
+} FeedItemInsertData;
+
+static void         graph_updated_cb                (GDBusConnection       *connection,
+                                                     const gchar           *sender_name,
+                                                     const gchar           *object_path,
+                                                     const gchar           *interface_name,
+                                                     const gchar           *signal_name,
+                                                     GVariant              *parameters,
+                                                     gpointer               user_data);
+static void         miner_started                   (TrackerMiner          *miner);
+static void         miner_stopped                   (TrackerMiner          *miner);
+static void         miner_paused                    (TrackerMiner          *miner);
+static void         miner_resumed                   (TrackerMiner          *miner);
+static void         retrieve_and_schedule_feeds     (TrackerMinerRSS       *miner);
+static gboolean     feed_channel_changed_timeout_cb (gpointer               user_data);
+static void         feed_channel_update_data_free   (FeedChannelUpdateData *fcud);
+static void         feed_item_insert_data_free      (FeedItemInsertData    *fiid);
+static void         feed_fetching_cb                (FeedsPool             *pool,
+                                                     FeedChannel           *feed,
+                                                     gpointer               user_data);
+static void         feed_ready_cb                   (FeedsPool             *pool,
+                                                     FeedChannel           *feed,
+                                                     GList                 *items,
+                                                     gpointer               user_data);
+static const gchar *get_message_url                 (FeedItem              *item);
 
 G_DEFINE_TYPE (TrackerMinerRSS, tracker_miner_rss, TRACKER_TYPE_MINER)
 
@@ -75,6 +101,11 @@ tracker_miner_rss_finalize (GObject *object)
 	g_dbus_connection_signal_unsubscribe (priv->connection, priv->graph_updated_id);
 	g_object_unref (priv->connection);
 
+	g_list_foreach (priv->item_inserts, (GFunc) feed_item_insert_data_free, NULL);
+	g_list_free (priv->item_inserts);
+
+	g_hash_table_unref (priv->channel_updates);
+
 	G_OBJECT_CLASS (tracker_miner_rss_parent_class)->finalize (object);
 }
 
@@ -94,20 +125,6 @@ tracker_miner_rss_class_init (TrackerMinerRSSClass *klass)
 	g_type_class_add_private (object_class, sizeof (TrackerMinerRSSPrivate));
 }
 
-static void
-graph_updated_cb (GDBusConnection *connection,
-                  const gchar     *sender_name,
-                  const gchar     *object_path,
-                  const gchar     *interface_name,
-                  const gchar     *signal_name,
-                  GVariant        *parameters,
-                  gpointer         user_data)
-{
-	g_message ("Subjects added or removed");
-
-	retrieve_and_schedule_feeds (user_data);
-}
-
 static void
 tracker_miner_rss_init (TrackerMinerRSS *object)
 {
@@ -127,9 +144,15 @@ tracker_miner_rss_init (TrackerMinerRSS *object)
 		return;
 	}
 
+	/* Key object reference is cleaned up in value destroy func */
+	priv->channel_updates = g_hash_table_new_full (g_direct_hash,
+	                                               g_direct_equal,
+	                                               NULL,
+	                                               (GDestroyNotify) feed_channel_update_data_free);
+
 	priv->pool = feeds_pool_new ();
-	g_signal_connect (priv->pool, "feed-fetching", G_CALLBACK (change_status), object);
-	g_signal_connect (priv->pool, "feed-ready", G_CALLBACK (feed_fetched), object);
+	g_signal_connect (priv->pool, "feed-fetching", G_CALLBACK (feed_fetching_cb), object);
+	g_signal_connect (priv->pool, "feed-ready", G_CALLBACK (feed_ready_cb), object);
 	priv->now_fetching = 0;
 
 	g_message ("Listening for GraphUpdated changes on D-Bus interface...");
@@ -148,30 +171,143 @@ tracker_miner_rss_init (TrackerMinerRSS *object)
 		                                     NULL);
 }
 
+
 static void
-verify_channel_update (GObject      *source,
-                       GAsyncResult *result,
-                       gpointer      user_data)
+graph_updated_cb (GDBusConnection *connection,
+                  const gchar     *sender_name,
+                  const gchar     *object_path,
+                  const gchar     *interface_name,
+                  const gchar     *signal_name,
+                  GVariant        *parameters,
+                  gpointer         user_data)
 {
-	GError *error;
+	TrackerMinerRSS *miner = TRACKER_MINER_RSS (user_data);
 
-	error = NULL;
+	g_message ("%s", signal_name);
+	g_message ("  Parameters:'%s'", g_variant_print (parameters, FALSE));
 
-	tracker_sparql_connection_update_finish (TRACKER_SPARQL_CONNECTION (source), result, &error);
-	if (error != NULL) {
-		g_critical ("Could not update channel information, %s", error->message);
-		g_error_free (error);
-	}
+	g_variant_unref (parameters);
+
+	retrieve_and_schedule_feeds (miner);
+}
+
+static FeedChannelUpdateData *
+feed_channel_update_data_new (TrackerMinerRSS *miner,
+                              FeedChannel     *channel)
+{
+	FeedChannelUpdateData *fcud;
+
+	fcud = g_slice_new0 (FeedChannelUpdateData);
+	fcud->miner = g_object_ref (miner);
+	fcud->channel = g_object_ref (channel);
+	fcud->timeout_id = g_timeout_add_seconds (2, feed_channel_changed_timeout_cb, fcud);
+	fcud->cancellable = g_cancellable_new ();
+
+	return fcud;
 }
 
 static void
-update_updated_interval (TrackerMinerRSS *miner,
-                         gchar           *uri,
-                         time_t          *now)
+feed_channel_update_data_free (FeedChannelUpdateData *fcud)
 {
-	TrackerSparqlBuilder *sparql;
+	if (!fcud) {
+		return;
+	}
 
-	g_message ("Updating mfo:updatedTime for channel '%s'", uri);
+	if (fcud->cancellable) {
+		g_cancellable_cancel (fcud->cancellable);
+		g_object_unref (fcud->cancellable);
+	}
+
+	if (fcud->timeout_id) {
+		g_source_remove (fcud->timeout_id);
+	}
+
+	if (fcud->channel) {
+		g_object_unref (fcud->channel);
+	}
+
+	if (fcud->miner) {
+		g_object_unref (fcud->miner);
+	}
+
+	g_slice_free (FeedChannelUpdateData, fcud);
+}
+
+static FeedItemInsertData *
+feed_item_insert_data_new (TrackerMinerRSS *miner,
+                           FeedItem        *item)
+{
+	FeedItemInsertData *fiid;
+
+	fiid = g_slice_new0 (FeedItemInsertData);
+	fiid->miner = g_object_ref (miner);
+	fiid->item = g_object_ref (item);
+	fiid->cancellable = g_cancellable_new ();
+
+	return fiid;
+}
+
+static void
+feed_item_insert_data_free (FeedItemInsertData *fiid)
+{
+	if (!fiid) {
+		return;
+	}
+
+	if (fiid->cancellable) {
+		g_cancellable_cancel (fiid->cancellable);
+		g_object_unref (fiid->cancellable);
+	}
+
+	if (fiid->item) {
+		g_object_unref (fiid->item);
+	}
+
+	if (fiid->miner) {
+		g_object_unref (fiid->miner);
+	}
+
+	g_slice_free (FeedItemInsertData, fiid);
+}
+
+static void
+feed_channel_change_updated_time_cb (GObject      *source,
+                                     GAsyncResult *result,
+                                     gpointer      user_data)
+{
+	TrackerMinerRSSPrivate *priv;
+	FeedChannelUpdateData *fcud;
+	GError *error = NULL;
+
+	fcud = user_data;
+	priv = TRACKER_MINER_RSS_GET_PRIVATE (fcud->miner);
+
+	tracker_sparql_connection_update_finish (TRACKER_SPARQL_CONNECTION (source), result, &error);
+	if (error != NULL) {
+		g_critical ("Could not change feed channel updated time, %s", error->message);
+		g_error_free (error);
+	}
+
+	/* This will clean up the fcud data too */
+	g_hash_table_remove (priv->channel_updates, fcud->channel);
+}
+
+static gboolean
+feed_channel_changed_timeout_cb (gpointer user_data)
+{
+	TrackerMinerRSSPrivate *priv;
+	TrackerSparqlBuilder *sparql;
+	FeedChannelUpdateData *fcud;
+	gchar *uri;
+	time_t now;
+
+	fcud = user_data;
+	priv = TRACKER_MINER_RSS_GET_PRIVATE (fcud->miner);
+
+	now = time (NULL);
+	uri = g_object_get_data (G_OBJECT (fcud->channel), "subject");
+
+	g_message ("Updating mfo:updatedTime for channel '%s'", feed_channel_get_title (fcud->channel));
 
 	/* I hope there will be soon a SPARQL command to just update a
 	 * value instead to delete and re-insert it
@@ -189,25 +325,57 @@ update_updated_interval (TrackerMinerRSS *miner,
 	tracker_sparql_builder_object_variable (sparql, "unknown");
 	tracker_sparql_builder_where_close (sparql);
 
-	tracker_sparql_builder_insert_open (sparql, uri);
+	tracker_sparql_builder_insert_open (sparql, NULL);
 	tracker_sparql_builder_subject_iri (sparql, uri);
 	tracker_sparql_builder_predicate (sparql, "mfo:updatedTime");
-	tracker_sparql_builder_object_date (sparql, now);
+	tracker_sparql_builder_object_date (sparql, &now);
 	tracker_sparql_builder_insert_close (sparql);
 
-	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
+	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (fcud->miner)),
 	                                        tracker_sparql_builder_get_result (sparql),
 	                                        G_PRIORITY_DEFAULT,
-	                                        NULL,
-	                                        verify_channel_update,
-	                                        NULL);
+	                                        fcud->cancellable,
+	                                        feed_channel_change_updated_time_cb,
+	                                        fcud);
 	g_object_unref (sparql);
+
+	return FALSE;
 }
 
 static void
-change_status (FeedsPool   *pool,
-               FeedChannel *feed,
-               gpointer     user_data)
+feed_channel_change_updated_time (FeedItemInsertData *fiid)
+{
+	TrackerMinerRSSPrivate *priv;
+	FeedChannel *channel;
+	FeedChannelUpdateData *fcud;
+
+	priv = TRACKER_MINER_RSS_GET_PRIVATE (fiid->miner);
+
+	/* Check we don't already have an update request for this channel */
+	channel = feed_item_get_parent (fiid->item);
+
+	fcud = g_hash_table_lookup (priv->channel_updates, channel);
+	if (fcud) {
+		/* We already had an update for this channel in
+		 * progress, so we just reset the timeout.
+		 */
+		g_source_remove (fcud->timeout_id);
+		fcud->timeout_id = g_timeout_add_seconds (2,
+		                                          feed_channel_changed_timeout_cb,
+		                                          fcud);
+	} else {
+		/* This is a new update for this channel */
+		fcud = feed_channel_update_data_new (fiid->miner, channel);
+		g_hash_table_insert (priv->channel_updates,
+		                     fcud->channel,
+		                     fcud);
+	}
+}
+
+static void
+feed_fetching_cb (FeedsPool   *pool,
+                  FeedChannel *channel,
+                  gpointer     user_data)
 {
 	gint avail;
 	gdouble prog;
@@ -223,8 +391,8 @@ change_status (FeedsPool   *pool,
 	if (priv->now_fetching > avail)
 		priv->now_fetching = avail;
 
-	g_message ("Fetching channel '%s' (in progress: %d/%d)",
-	           feed_channel_get_source (feed),
+	g_message ("Fetching channel details, source:'%s' (in progress: %d/%d)",
+	           feed_channel_get_source (channel),
 	           priv->now_fetching,
 	           avail);
 
@@ -233,26 +401,40 @@ change_status (FeedsPool   *pool,
 }
 
 static void
-verify_item_insertion (GObject      *source,
-                       GAsyncResult *result,
-                       gpointer      user_data)
+feed_item_insert_cb (GObject      *source,
+                     GAsyncResult *result,
+                     gpointer      user_data)
 {
+	FeedItemInsertData *fiid;
+	FeedChannel *channel;
 	GError *error;
+	const gchar *title;
 
+	fiid = user_data;
+	channel = feed_item_get_parent (fiid->item);
+	title = feed_item_get_title (fiid->item);
 	error = NULL;
 
 	tracker_sparql_connection_update_finish (TRACKER_SPARQL_CONNECTION (source), result, &error);
 	if (error != NULL) {
-		g_critical ("Could not insert feed information, %s", error->message);
+		g_critical ("Could not insert feed information for message titled:'%s', %s",
+		            title,
+		            error->message);
 		g_error_free (error);
+	} else {
+		feed_channel_change_updated_time (fiid);
 	}
+
+	feed_item_insert_data_free (fiid);
 }
 
 static void
-item_verify_reply_cb (GObject      *source_object,
-                      GAsyncResult *res,
-                      gpointer      user_data)
+feed_item_check_exists_cb (GObject      *source_object,
+                           GAsyncResult *res,
+                           gpointer      user_data)
 {
+	TrackerSparqlConnection *connection;
+	FeedItemInsertData *fiid;
 	time_t t;
 	gchar *uri;
 	const gchar *str;
@@ -263,48 +445,62 @@ item_verify_reply_cb (GObject      *source_object,
 	TrackerSparqlCursor *cursor;
 	GError *error;
 	TrackerSparqlBuilder *sparql;
-	FeedItem *item;
-	FeedChannel *feed;
-	TrackerMinerRSS *miner;
+	FeedChannel *channel;
 	gboolean has_geolocation;
 
-	miner = TRACKER_MINER_RSS (source_object);
+	fiid = user_data;
+	connection = TRACKER_SPARQL_CONNECTION (source_object);
 	error = NULL;
-	cursor = tracker_sparql_connection_query_finish (TRACKER_SPARQL_CONNECTION (source_object),
-	                                                 res,
-	                                                 &error);
+	cursor = tracker_sparql_connection_query_finish (connection, res, &error);
 
 	if (error != NULL) {
 		g_message ("Could not verify feed existance, %s", error->message);
 		g_error_free (error);
+
 		if (cursor) {
 			g_object_unref (cursor);
 		}
+
+		feed_item_insert_data_free (fiid);
+
 		return;
 	}
 
 	if (!tracker_sparql_cursor_next (cursor, NULL, NULL)) {
 		g_message ("No data in query response??");
-		g_object_unref (cursor);
+
+		if (cursor) {
+			g_object_unref (cursor);
+		}
+
+		feed_item_insert_data_free (fiid);
+
 		return;
 	}
 
+	url = get_message_url (fiid->item);
+	channel = feed_item_get_parent (fiid->item);
+
 	str = tracker_sparql_cursor_get_string (cursor, 0, NULL);
-	if (g_strcmp0 (str, "1") == 0) {
-		g_object_unref (cursor);
+	if (str && g_ascii_strcasecmp (str, "true") == 0) {
+		g_message ("  Item already exists '%s'",
+		           feed_item_get_title (fiid->item));
+
+		if (cursor) {
+			g_object_unref (cursor);
+		}
+
+		feed_item_insert_data_free (fiid);
+
 		return;
 	}
 
-	item = user_data;
-
-	url = get_message_url (item);
-
-	g_message ("Updating feed information for '%s'", url);
+	g_message ("Inserting feed item for '%s'", url);
 
 	sparql = tracker_sparql_builder_new_update ();
 
-	has_geolocation = feed_item_get_geo_point (item, &latitude, &longitude);
-	tracker_sparql_builder_insert_open (sparql, url);
+	has_geolocation = feed_item_get_geo_point (fiid->item, &latitude, &longitude);
+	tracker_sparql_builder_insert_open (sparql, NULL);
 
 	if (has_geolocation) {
 		g_message ("  Geolocation, using longitude:%f, latitude:%f",
@@ -331,7 +527,7 @@ item_verify_reply_cb (GObject      *source_object,
 		tracker_sparql_builder_object (sparql, "_:location");
 	}
 
-	tmp_string = feed_item_get_title (item);
+	tmp_string = feed_item_get_title (fiid->item);
 	if (tmp_string != NULL) {
 		g_message ("  Title:'%s'", tmp_string);
 
@@ -339,7 +535,7 @@ item_verify_reply_cb (GObject      *source_object,
 		tracker_sparql_builder_object_unvalidated (sparql, tmp_string);
 	}
 
-	tmp_string = feed_item_get_description (item);
+	tmp_string = feed_item_get_description (fiid->item);
 	if (tmp_string != NULL) {
 		tracker_sparql_builder_predicate (sparql, "nie:plainTextContent");
 		tracker_sparql_builder_object_unvalidated (sparql, tmp_string);
@@ -361,35 +557,35 @@ item_verify_reply_cb (GObject      *source_object,
 	tracker_sparql_builder_predicate (sparql, "mfo:downloadedTime");
 	tracker_sparql_builder_object_date (sparql, &t);
 
-	t = feed_item_get_publish_time (item);
+	t = feed_item_get_publish_time (fiid->item);
 	tracker_sparql_builder_predicate (sparql, "nie:contentCreated");
 	tracker_sparql_builder_object_date (sparql, &t);
 
 	tracker_sparql_builder_predicate (sparql, "nmo:isRead");
 	tracker_sparql_builder_object_boolean (sparql, FALSE);
 
-	feed = feed_item_get_parent (item);
-	uri = g_object_get_data (G_OBJECT (feed), "subject");
+	uri = g_object_get_data (G_OBJECT (channel), "subject");
 	tracker_sparql_builder_predicate (sparql, "nmo:communicationChannel");
 	tracker_sparql_builder_object_iri (sparql, uri);
 
 	tracker_sparql_builder_insert_close (sparql);
 
-	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
+	tracker_sparql_connection_update_async (connection,
 	                                        tracker_sparql_builder_get_result (sparql),
 	                                        G_PRIORITY_DEFAULT,
-	                                        NULL,
-	                                        verify_item_insertion,
-	                                        NULL);
+	                                        fiid->cancellable,
+	                                        feed_item_insert_cb,
+	                                        fiid);
 
 	g_object_unref (cursor);
 	g_object_unref (sparql);
 }
 
 static void
-check_if_save (TrackerMinerRSS *miner,
-               FeedItem        *item)
+feed_item_check_exists (TrackerMinerRSS *miner,
+                        FeedItem        *item)
 {
+	FeedItemInsertData *fiid;
 	FeedChannel *feed;
 	gchar *query;
 	gchar *communication_channel;
@@ -399,33 +595,33 @@ check_if_save (TrackerMinerRSS *miner,
 	feed = feed_item_get_parent (item);
 	communication_channel = g_object_get_data (G_OBJECT (feed), "subject");
 
-	g_debug ("Verifying feed '%s' is stored", url);
-
-	query = g_strdup_printf ("ASK { ?message a mfo:FeedMessage; "
-	                         "nie:url \"%s\"; nmo:communicationChannel <%s> }",
+	query = g_strdup_printf ("ASK {"
+	                         "  ?message a mfo:FeedMessage ;"
+	                         "             nie:url \"%s\";"
+	                         "             nmo:communicationChannel <%s> "
+	                         "}",
 	                         url,
 	                         communication_channel);
 
+	fiid = feed_item_insert_data_new (miner, item);
+
 	tracker_sparql_connection_query_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
 	                                       query,
-	                                       NULL,
-	                                       item_verify_reply_cb,
-	                                       item);
+	                                       fiid->cancellable,
+	                                       feed_item_check_exists_cb,
+	                                       fiid);
 	g_free (query);
 }
 
 static void
-feed_fetched (FeedsPool   *pool,
-              FeedChannel *feed,
-              GList       *items,
-              gpointer     user_data)
+feed_ready_cb (FeedsPool   *pool,
+               FeedChannel *channel,
+               GList       *items,
+               gpointer     user_data)
 {
-	gchar *uri;
-	time_t now;
-	GList *iter;
-	FeedItem *item;
 	TrackerMinerRSS *miner;
 	TrackerMinerRSSPrivate *priv;
+	GList *iter;
 
 	miner = TRACKER_MINER_RSS (user_data);
 	priv = TRACKER_MINER_RSS_GET_PRIVATE (miner);
@@ -439,16 +635,17 @@ feed_fetched (FeedsPool   *pool,
 		g_object_set (miner, "progress", 1.0, "status", "Idle", NULL);
 	}
 
-	if (items == NULL)
+	if (items == NULL) {
 		return;
+	}
 
-	now = time (NULL);
-	uri = g_object_get_data (G_OBJECT (feed), "subject");
-	update_updated_interval (miner, uri, &now);
+	g_message ("Verifying channel:'%s' is up to date",
+	           feed_channel_get_title (channel));
 
 	for (iter = items; iter; iter = iter->next) {
-		item = iter->data;
-		check_if_save (miner, item);
+		FeedItem *item = iter->data;
+
+		feed_item_check_exists (miner, item);
 	}
 }
 
@@ -480,19 +677,23 @@ feeds_retrieve_cb (GObject      *source_object,
 	channels = NULL;
 	count = 0;
 
-	g_message ("Found feeds");
-
 	while (tracker_sparql_cursor_next (cursor, NULL, NULL)) {
 		const gchar *source;
+		const gchar *title;
 		const gchar *interval;
 		const gchar *subject;
 		gint mins;
 
+		if (count == 0) {
+			g_message ("Feeds found:");
+		}
+
 		count++;
 
 		source = tracker_sparql_cursor_get_string (cursor, 0, NULL);
-		interval = tracker_sparql_cursor_get_string (cursor, 1, NULL);
-		subject = tracker_sparql_cursor_get_string (cursor, 2, NULL);
+		title = tracker_sparql_cursor_get_string (cursor, 1, NULL);
+		interval = tracker_sparql_cursor_get_string (cursor, 2, NULL);
+		subject = tracker_sparql_cursor_get_string (cursor, 3, NULL);
 
 		chan = feed_channel_new ();
 		g_object_set_data_full (G_OBJECT (chan),
@@ -510,9 +711,18 @@ feeds_retrieve_cb (GObject      *source_object,
 			mins = 1;
 		feed_channel_set_update_interval (chan, mins);
 
+		g_message ("  '%s' (%s) - update interval of %s minutes",
+		           title,
+		           source,
+		           interval);
+
 		channels = g_list_prepend (channels, chan);
 	}
 
+	if (count == 0) {
+		g_message ("No feeds set up, nothing more to do");
+	}
+
 	priv = TRACKER_MINER_RSS_GET_PRIVATE (user_data);
 	feeds_pool_listen (priv->pool, channels);
 
@@ -530,11 +740,14 @@ retrieve_and_schedule_feeds (TrackerMinerRSS *miner)
 
 	g_message ("Retrieving and scheduling feeds...");
 
-	sparql = "SELECT ?chanUrl ?interval ?chanUrn WHERE "
-		"{ ?chanUrn a mfo:FeedChannel . "
-		"?chanUrn mfo:feedSettings ?settings . "
-		"?chanUrn nie:url ?chanUrl . "
-		"?settings mfo:updateInterval ?interval }";
+	sparql =
+		"SELECT ?url nie:title(?urn) ?interval ?urn "
+		"WHERE {"
+		"  ?urn a mfo:FeedChannel ; "
+		"         mfo:feedSettings ?settings ; "
+		"         nie:url ?url . "
+		"  ?settings mfo:updateInterval ?interval "
+		"}";
 
 	tracker_sparql_connection_query_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
 	                                       sparql,
