@@ -24,11 +24,13 @@
 #define _GNU_SOURCE
 #endif
 
+#include <errno.h>
 #include <fcntl.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <sys/mman.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -175,11 +177,11 @@ extract_abw (const gchar          *uri,
              TrackerSparqlBuilder *preupdate,
              TrackerSparqlBuilder *metadata)
 {
-	GMappedFile *file;
+	int fd;
 	gchar *filename, *contents;
 	GError *error = NULL;
-	gboolean retval = FALSE;
 	gsize len;
+	struct stat st;
 
 	filename = g_filename_from_uri (uri, NULL, &error);
 
@@ -189,19 +191,48 @@ extract_abw (const gchar          *uri,
 		return;
 	}
 
-	file = g_mapped_file_new (filename, FALSE, &error);
-	g_free (filename);
+	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
+	if (fd == -1 && errno == EPERM) {
+		fd = g_open (filename, O_RDONLY, 0);
+	}
 
-	if (error) {
-		g_warning ("Could not mmap abw file: %s\n", error->message);
-		g_error_free (error);
+	if (fd == -1) {
+		g_warning ("Could not open abw file '%s': %s\n",
+		           filename,
+		           g_strerror (errno));
+		g_free (filename);
 		return;
 	}
 
-	contents = g_mapped_file_get_contents (file);
-	len = g_mapped_file_get_length (file);
+	if (fstat (fd, &st) == -1) {
+		g_warning ("Could not fstat abw file '%s': %s\n",
+		           filename,
+		           g_strerror (errno));
+		close (fd);
+		g_free (filename);
+		return;
+	}
+
+	if (st.st_size == 0) {
+		contents = NULL;
+		len = 0;
+	} else {
+		contents = (gchar *) mmap (NULL, st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+		if (contents == NULL) {
+			g_warning ("Could not mmap abw file '%s': %s\n",
+			           filename,
+			           g_strerror (errno));
+			close (fd);
+			g_free (filename);
+			return;
+		}
+		len = st.st_size;
+	}
+
+	g_free (filename);
 
 	if (contents) {
+		GError *error = NULL;
 		GMarkupParseContext *context;
 		AbwParserData data = { 0 };
 
@@ -224,13 +255,16 @@ extract_abw (const gchar          *uri,
 				g_string_free (data.content, TRUE);
 			}
 
-			retval = TRUE;
 		}
 
 		g_markup_parse_context_free (context);
 	}
 
-	g_mapped_file_unref (file);
+	if (contents) {
+		munmap (contents, len);
+	}
+
+	close (fd);
 }
 
 TrackerExtractData *
